@@ -5,26 +5,41 @@ from mopidy import backend
 
 logger = logging.getLogger(__name__)
 
-from .library import Library
-from .playback import Playback
-from .httpclient import HttpClientConfig
-from .uri_parser import root_uri
+from . import library
+from . import playback
+from . import httpclient
+from . import uri_parser
 
+def parse_raw_options(raw_options):
+    if not raw_options:
+        return {}
+
+    options = {}
+    for raw_option in raw_options.split("&"):
+        key, value = raw_option.split("=")
+        options[key] = value
+
+    return options
 
 def load_http_client_config(provider):
-    match = re.match(r'^([^:]+):(?: )?([^:]+)://([^:]+):([^@]+)@(.+)', provider)
+    match = re.match(r'^([^:]+):(?: )?([^:]+)://([^:]+):([^@]+)@([^?]+)(\?(.+))?', provider)
 
     name=match.group(1)
     protocol=match.group(2)
     username=match.group(3)
     password=match.group(4)
     url=match.group(5)
+    raw_options=match.group(7)
 
-    return HttpClientConfig(
+    options = parse_raw_options(raw_options)
+
+    return httpclient.HttpClientConfig(
         name=name,
         url=protocol + "://" + url,
         username=username,
-        password=password
+        password=password,
+        max_bit_rate=options.get("max_bit_rate"),
+        format=options.get("format")
     )
 
 def load_http_client_configs(config):
@@ -40,6 +55,6 @@ class MultisonicBackend(pykka.ThreadingActor, backend.Backend):
         self.audio = audio
         self.http_client_configs = load_http_client_configs(self.config)
 
-        self.library = Library(self)
-        self.playback = Playback(audio, self)
-        self.uri_schemes = [root_uri]
+        self.library = library.Library(self)
+        self.playback = playback.Playback(audio, self)
+        self.uri_schemes = [uri_parser.root_uri]
