@@ -1,7 +1,7 @@
 from mopidy import backend
 from . import uri_parser
-from .httpclient import get_stream
-from .browser import get_http_client_config
+from . import httpclient
+from . import browser
 
 class Playback(backend.PlaybackProvider):
     def __init__(self, audio, backend):
@@ -12,7 +12,7 @@ class Playback(backend.PlaybackProvider):
         return self.backend.http_client_configs
 
     def translate_uri(self, uri):
-        http_client_config = get_http_client_config(self.get_http_client_configs(), uri)
+        http_client_config = browser.get_http_client_config(self.get_http_client_configs(), uri)
         id = uri_parser.get_id(uri)
-        return get_stream(http_client_config, str(id)).url
+        return httpclient.get_stream(http_client_config, str(id)).url
 
